==> gnome-shell-calculate-3.2.2.5.tar.bz2: gnome-shell-calculate-3.2.2.5/extensions/trayicons@calculate-linux.org/extension.js <==
const Clutter = imports.gi.Clutter;
const StatusIconDispatcher = imports.ui.statusIconDispatcher;
const Main = imports.ui.main;
const Lang = imports.lang;
const St = imports.gi.St;
const Panel = imports.ui.main.panel;
const AutorunManager = imports.ui.autorunManager;
const MessageTray = imports.ui.messageTray;

let removeStatusIcon = [
    'a11y',         // Accessibility
    'bluetooth'    // Bluetooth
    // 'volume',
    // 'battery',
    // 'keyboard',
    // 'network'
]

let iconConnectId = null;
let oldemit = null;
let origRedisplay = null;
let originit = null;
let origCorner = null;

function _onTrayIconAdded(o,icon) {
    let wmClass = (icon.wm_class || 'unknown').toLowerCase();
    let role = StatusIconDispatcher.STANDARD_TRAY_ICON_IMPLEMENTATIONS[wmClass] || wmClass;
    Main.statusIconDispatcher.oldemit('status-icon-added',icon,role);
    if(role == "glipper") {
        parentActor = icon.get_parent();
        parentActor.remove_actor(icon);
        let newBin = new St.BoxLayout();
        let newIcon = new St.Icon({icon_name:"edit-cut",
                                 icon_type: St.IconType.FULLCOLOR,
                                style_class: 'system-status-icon'})
        parentActor.add_actor(newBin);
        newBin.add(newIcon);
        icon.reparent(newBin);
        icon.set_position(0,0);
        icon.opacity = 0;
    }
}


function _onTrayIconRemoved(o,icon) {
    Main.statusIconDispatcher.oldemit('status-icon-removed',icon);
}

function enable() {
    Main.statusIconDispatcher.oldemit = Main.statusIconDispatcher.emit;
    Main.statusIconDispatcher.emit = function() {};
    iconConnectId = Main.statusIconDispatcher._traymanager.connect('tray-icon-added',
        Lang.bind(Main.statusIconDispatcher,_onTrayIconAdded));
    iconRemoveConnectId = Main.statusIconDispatcher._traymanager.connect('tray-icon-removed',
        Lang.bind(Main.statusIconDispatcher,_onTrayIconRemoved));
    for(let e=0;e < removeStatusIcon.length;e++) {
        Panel._statusArea[removeStatusIcon[e]].actor.hide();
    }
    origRedisplay = AutorunManager.AutorunResidentSource.prototype._redisplay;
    origInit = AutorunManager.AutorunTransientSource.prototype._init;
    origOnCornerEnter = MessageTray.MessageTray.prototype._onCornerEnter;
    AutorunManager.AutorunResidentSource.prototype._redisplay = function () {}
    AutorunManager.AutorunTransientSource.prototype._init = function(mount,apps) {}

    origCorner = Main.messageTray._corner;
    Main.layoutManager.trayBox.remove_actor(Main.messageTray._corner);
    Main.layoutManager.untrackChrome(Main.messageTray._corner);
    Main.messageTray._corner = new Clutter.Rectangle({ width: 1,
                                           height: 1,
                                           opacity: 0,
                                           reactive: true });
    Main.messageTray._corner.connect('enter-event', Lang.bind(Main.messageTray, function(actor, event) {
        if(this._summary.get_children().length) {
            this._pointerInSummary = true;
            this._updateState();
        }
    }));
    Main.layoutManager.trayBox.add_actor(Main.messageTray._corner);
    Main.messageTray._corner.x = Main.layoutManager.trayBox.width - 1;
    Main.messageTray._corner.y = Main.layoutManager.trayBox.height - 1;
    Main.layoutManager.trackChrome(Main.messageTray._corner);
}

function init() {
}

function disable() {
    Main.statusIconDispatcher._traymanager.disconnect(iconConnectId);
    Main.statusIconDispatcher._traymanager.disconnect(iconRemoveConnectId);
    Main.statusIconDispatcher.emit = Main.statusIconDispatcher.oldemit;
    for(let e=0;e < removeStatusIcon.length;e++) {
        Panel._statusArea[removeStatusIcon[e]].actor.show();
    }
    AutorunManager.AutorunResidentSource.prototype._redisplay = origRedisplay;
    AutorunManager.AutorunTransientSource.prototype._init = origInit;

    Main.layoutManager.trayBox.remove_actor(Main.messageTray._corner);
    Main.layoutManager.untrackChrome(Main.messageTray._corner);
    Main.messageTray._corner = origCorner;
    Main.layoutManager.trayBox.add_actor(Main.messageTray._corner);
    Main.messageTray._corner.x = Main.layoutManager.trayBox.width - 1;
    Main.messageTray._corner.y = Main.layoutManager.trayBox.height - 1;
    Main.layoutManager.trackChrome(Main.messageTray._corner);
}

==> gnome-shell-calculate-3.2.2.8.tar.bz2: gnome-shell-calculate-3.2.2.8/extensions/trayicons@calculate-linux.org/extension.js <==
const Clutter = imports.gi.Clutter;
const StatusIconDispatcher = imports.ui.statusIconDispatcher;
const Main = imports.ui.main;
const Lang = imports.lang;
const St = imports.gi.St;
const Panel = imports.ui.main.panel;
const AutorunManager = imports.ui.autorunManager;
const MessageTray = imports.ui.messageTray;

let removeStatusIcon = [
    'a11y',         // Accessibility
    'bluetooth'    // Bluetooth
    // 'volume',
    // 'battery',
    // 'keyboard',
    // 'network'
]

let iconConnectId = null;
let oldemit = null;
let origRedisplay = null;
let origInit = null;
let origCorner = null;
let origOnCornerEnter = null;
let iconRemoveConnectId = null;

function _onTrayIconAdded(o,icon) {
    let wmClass = (icon.wm_class || 'unknown').toLowerCase();
    let role = StatusIconDispatcher.STANDARD_TRAY_ICON_IMPLEMENTATIONS[wmClass] || wmClass;
    Main.statusIconDispatcher.oldemit('status-icon-added',icon,role);
    if(role == "glipper") {
        let parentActor = icon.get_parent();
        parentActor.remove_actor(icon);
        let newBin = new St.BoxLayout();
        let newIcon = new St.Icon({icon_name:"edit-cut",
                                 icon_type: St.IconType.FULLCOLOR,
                                style_class: 'system-status-icon'})
        parentActor.add_actor(newBin);
        newBin.add(newIcon);
        icon.reparent(newBin);
        icon.set_position(0,0);
        icon.opacity = 0;
    }
}


function _onTrayIconRemoved(o,icon) {
    Main.statusIconDispatcher.oldemit('status-icon-removed',icon);
}

function enable() {
    Main.statusIconDispatcher.oldemit = Main.statusIconDispatcher.emit;
    Main.statusIconDispatcher.emit = function() {};
    iconConnectId = Main.statusIconDispatcher._traymanager.connect('tray-icon-added',
        Lang.bind(Main.statusIconDispatcher,_onTrayIconAdded));
    iconRemoveConnectId = Main.statusIconDispatcher._traymanager.connect('tray-icon-removed',
        Lang.bind(Main.statusIconDispatcher,_onTrayIconRemoved));
    for(let e=0;e < removeStatusIcon.length;e++) {
        Panel._statusArea[removeStatusIcon[e]].actor.hide();
    }
    origRedisplay = AutorunManager.AutorunResidentSource.prototype._redisplay;
    origInit = AutorunManager.AutorunTransientSource.prototype._init;
    origOnCornerEnter = MessageTray.MessageTray.prototype._onCornerEnter;
    AutorunManager.AutorunResidentSource.prototype._redisplay = function () {}
    AutorunManager.AutorunTransientSource.prototype._init = function(mount,apps) {}

    origCorner = Main.messageTray._corner;
    Main.layoutManager.trayBox.remove_actor(Main.messageTray._corner);
    Main.layoutManager.untrackChrome(Main.messageTray._corner);
    Main.messageTray._corner = new Clutter.Rectangle({ width: 1,
                                           height: 1,
                                           opacity: 0,
                                           reactive: true });
    Main.messageTray._corner.connect('enter-event', Lang.bind(Main.messageTray, function(actor, event) {
        if(this._summary.get_children().length) {
            this._pointerInSummary = true;
            this._updateState();
        }
    }));
    Main.layoutManager.trayBox.add_actor(Main.messageTray._corner);
    Main.messageTray._corner.x = Main.layoutManager.trayBox.width - 1;
    Main.messageTray._corner.y = Main.layoutManager.trayBox.height - 1;
    Main.layoutManager.trackChrome(Main.messageTray._corner);
}

function init() {
}

function disable() {
    Main.statusIconDispatcher._traymanager.disconnect(iconConnectId);
    Main.statusIconDispatcher._traymanager.disconnect(iconRemoveConnectId);
    Main.statusIconDispatcher.emit = Main.statusIconDispatcher.oldemit;
    for(let e=0;e < removeStatusIcon.length;e++) {
        Panel._statusArea[removeStatusIcon[e]].actor.show();
    }
    AutorunManager.AutorunResidentSource.prototype._redisplay = origRedisplay;
    AutorunManager.AutorunTransientSource.prototype._init = origInit;

    Main.layoutManager.trayBox.remove_actor(Main.messageTray._corner);
    Main.layoutManager.untrackChrome(Main.messageTray._corner);
    Main.messageTray._corner = origCorner;
    Main.layoutManager.trayBox.add_actor(Main.messageTray._corner);
    Main.messageTray._corner.x = Main.layoutManager.trayBox.width - 1;
    Main.messageTray._corner.y = Main.layoutManager.trayBox.height - 1;
    Main.layoutManager.trackChrome(Main.messageTray._corner);
}
